==> kdeutils-4.1.2.tar.bz2: kdeutils-4.1.2/okteta/core/kbookmarkable.h <==
/*
    This file is part of the Okteta Core library, part of the KDE project.

    Copyright 2007 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KHE_CORE_BOOKMARKABLE_H
#define KHE_CORE_BOOKMARKABLE_H

// lib
#include "kbookmarklist.h"
// Qt
#include <QtCore/QtPlugin>
#include <QtCore/QList>

namespace KHECore
{
// TODO: add and remove with lists, not only single items
class Bookmarkable
{
  public:
    virtual ~Bookmarkable();

  public: // set/action
    virtual void addBookmarks( const QList<KHECore::KBookmark> &bookmarks ) = 0;
    virtual void removeBookmarks( const QList<KHECore::KBookmark> &bookmarks ) = 0;
    virtual void removeAllBookmarks() = 0;

  public: // get
    virtual KHECore::KBookmarkList bookmarkList() const = 0;

  public: // signal
    virtual void bookmarksAdded( const QList<KHECore::KBookmark> &bookmarks ) = 0;
    virtual void bookmarksRemoved( const QList<KHECore::KBookmark> &bookmarks ) = 0;
//     virtual void bookmarksModified( const QList<KHECore::KBookmark> &bookmarks ) = 0; TODO; signal which changed?
    virtual void bookmarksModified( bool modified ) = 0;
};

inline Bookmarkable::~Bookmarkable() {}

}

Q_DECLARE_INTERFACE( KHECore::Bookmarkable, "org.kde.khecore.bookmarkable/1.0" )

#endif

==> kdeutils-4.2.1.tar.bz2: kdeutils-4.2.1/okteta/core/kbookmarkable.h <==
/*
    This file is part of the Okteta Core library, part of the KDE project.

    Copyright 2007 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KHE_CORE_BOOKMARKABLE_H
#define KHE_CORE_BOOKMARKABLE_H

// lib
#include "bookmarklist.h"
// Qt
#include <QtCore/QtPlugin>
#include <QtCore/QList>

namespace KHECore
{
// TODO: add and remove with lists, not only single items
class Bookmarkable
{
  public:
    virtual ~Bookmarkable();

  public: // set/action
    virtual void addBookmarks( const QList<KHECore::Bookmark> &bookmarks ) = 0;
    virtual void removeBookmarks( const QList<KHECore::Bookmark> &bookmarks ) = 0;
    virtual void removeAllBookmarks() = 0;

  public: // get
    virtual KHECore::BookmarkList bookmarkList() const = 0;

  public: // signal
    virtual void bookmarksAdded( const QList<KHECore::Bookmark> &bookmarks ) = 0;
    virtual void bookmarksRemoved( const QList<KHECore::Bookmark> &bookmarks ) = 0;
//     virtual void bookmarksModified( const QList<KHECore::Bookmark> &bookmarks ) = 0; TODO; signal which changed?
    virtual void bookmarksModified( bool modified ) = 0;
};

inline Bookmarkable::~Bookmarkable() {}

}

Q_DECLARE_INTERFACE( KHECore::Bookmarkable, "org.kde.khecore.bookmarkable/1.0" )

#endif
